ButtonRing Example
===============================================================================

:download:`button_ring.enaml <../../../examples/layout/advanced/button_ring.enaml>`

.. literalinclude:: ../../../examples/layout/advanced/button_ring.enaml
    :language: python

::

 $ enaml-run button_ring.enaml

.. image:: images/button_ring.png
